## Not run:
# data(vnf)
# ## First the number of components has to be chosen
# ## (for the reconstruction step)
# ## nb <- estim_ncpMCA(vnf,ncp.max=5) ## Time-consuming, nb = 4
#
# ## Impute the indicator matrix and perform a MCA
# res.impute <- imputeMCA(vnf, ncp=4)
#
# ## The imputed indicator matrix can be used as an input of the MCA function of the
# ## FactoMineR package to perform the MCA on the incomplete data vnf
# res.mca <- MCA(vnf,tab.disj=res.impute$tab.disj)
#
# ## With supplementary variables (var 11 to 14), impute the active ones
# res.impute <- imputeMCA(vnf[,1:10], ncp=4)
# res.mca <- MCA(vnf,tab.disj=res.impute$tab.disj,quali.sup=11:14)
# ## End(Not run)
Run the code above in your browser using DataLab